# Generated by Django 4.0.6 on 2022-07-12 09:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('SMS', '0002_delete_smstoken'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='smslog',
            name='code',
        ),
    ]



# Generated by Django 4.0.6 on 2022-07-12 09:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('SMS', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='SmsToken',
        ),
    ]



from rest_framework import serializers
from django.utils.translation import gettext_lazy as _


class ValidatePhoneNumber(serializers.Serializer):
    phone_number = serializers.CharField()
    message = serializers.CharField()

    def validate_phone_number(self, phone_number):
        self._errors = []
        if len(phone_number) != 12:
            message = _(
                "Phone number must have 12 characters and"
                " format should be '998xxxxxxxxx'")
            self._errors.append(message)

        if self._errors:
            raise serializers.ValidationError(self._errors)
        return phone_number
    



from django.contrib import admin
from .models import SmsLog


class SmsLogAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "phone_number",
        "text",
        "is_active",
    )
    list_display_links = ("id", "phone_number")
    list_editable = ("is_active",)


admin.site.register(SmsLog, SmsLogAdmin)


# Generated by Django 4.0.6 on 2022-07-12 09:07

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SmsLog',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone_number', models.CharField(max_length=35)),
                ('code', models.IntegerField()),
                ('text', models.CharField(max_length=255)),
                ('is_active', models.BooleanField(default=True)),
            ],
            options={
                'verbose_name': 'Log',
                'verbose_name_plural': 'Logs',
            },
        ),
        migrations.CreateModel(
            name='SmsToken',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.TextField()),
                ('created_at', models.DateField()),
                ('expires_at', models.DateField()),
            ],
            options={
                'verbose_name': 'Token',
                'verbose_name_plural': 'Token',
                'ordering': ('-id',),
            },
        ),
    ]



from django.db import models

# Create your models here.
from django.db import models
from django.utils.translation import gettext_lazy as _




class SmsLog(models.Model):
    phone_number = models.CharField(max_length=35)
    text = models.CharField(max_length=255)
    is_active = models.BooleanField(default=True)


    class Meta:
        verbose_name = "Log"
        verbose_name_plural = "Logs"
        # ordering = ["-id"]

    def __str__(self):
        return self.phone_number




import requests
from django.conf import settings
import json
from dataclasses import dataclass
from .models import SmsLog

# initializing variables
SMS_ENDPOINT = settings.SMS_SETTINGS['SMS_URL']
SMS_LOGIN = settings.SMS_SETTINGS['SMS_LOGIN']
SMS_PASSWORD =  settings.SMS_SETTINGS['SMS_PASSWORD']
# end of initializing variables

@dataclass
class SMS_Sender:
    number: int
    message: str

    def SendSmsOneContact(self):
        try:
            dt = {
                "messages": [
                    {
                        "recipient": self.number,
                        "message-id": "abc000000001",
                        "sms": {
                            "originator": "3700",
                            "content": {
                                "text": self.message
                            }
                        }
                    }
                ]
            }
            # Logging the SMS
            self.create_sms_log(phone_number = self.number, message = self.message)
            return requests.post(url=SMS_ENDPOINT, auth=(SMS_LOGIN, SMS_PASSWORD), headers={'content-type': 'application/json'}, data=json.dumps(dt))

        except Exception as e:
            return f'Error: {str(e)}'

    def create_sms_log(self, phone_number, message):
        SmsLog.objects.create(
            phone_number=phone_number, text=message)




from django.shortcuts import render

# Create your views here.
from rest_framework.permissions import AllowAny
from rest_framework.views import APIView, Response

from .serializers import ValidatePhoneNumber  # noqa

from .sms_utils import SMS_Sender  # noqa


class SendSmsAPIView(APIView):
    permission_classes = [AllowAny]
    serializer_class = ValidatePhoneNumber

    def post(self, request):
        serializer = self.serializer_class(data=request.data)
        serializer.is_valid(raise_exception=True)
        phone_number = serializer.validated_data["phone_number"]
        message = serializer.validated_data["message"]
        configuration = SMS_Sender(phone_number, message)


        result = configuration.SendSmsOneContact()
        return Response(result)


send_sms_api_view = SendSmsAPIView.as_view()